==> qtjambi-multimedia-debuginfo-linux-x64-6.5.7.jar: sources/QtJambiMultimedia/QAudioInput_shell.h <==
#ifndef QAUDIOINPUT_SHELL_H
#define QAUDIOINPUT_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtMultimedia/qaudioinput.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtMultimedia/qaudiodevice.h>
#include <QtJambi/RegistryAPI>


class QAudioInput_shell : public QAudioInput, public QtJambiShellInterface
{
public:
    QAudioInput_shell(const QAudioDevice& deviceInfo0, QObject* parent1 = nullptr);
    QAudioInput_shell(QObject* parent0 = nullptr);
    ~QAudioInput_shell() override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    friend class QAudioInput_mshell;
    friend class QAudioInput_oshell;
};


class QAudioInput_mshell : public QAudioInput_shell
{
public:
    using QAudioInput_shell::QAudioInput_shell;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
};


class QAudioInput_oshell : public QAudioInput_mshell
{
public:
    using QAudioInput_mshell::QAudioInput_mshell;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
private:
    jmethodID __shell_javaMethod(int pos) const;
};

struct QAudioInput_access : public QAudioInput
{
};

#endif // QAUDIOINPUT_SHELL_H

==> qtjambi-multimedia-debuginfo-linux-x64-6.6.2.jar: sources/QtJambiMultimedia/QAudioInput_shell.h <==
#ifndef QAUDIOINPUT_SHELL_H
#define QAUDIOINPUT_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtMultimedia/qaudioinput.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qvariant.h>
#include <QtMultimedia/qaudiodevice.h>
#include <QtJambi/RegistryAPI>


class QAudioInput_shell : public QAudioInput, public QtJambiShellInterface
{
public:
    QAudioInput_shell(const QAudioDevice& deviceInfo0, QObject* parent1 = nullptr);
    QAudioInput_shell(QObject* parent0 = nullptr);
    ~QAudioInput_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QAudioInput_access : public QAudioInput
{
};

#endif // QAUDIOINPUT_SHELL_H
